==> xl-react-components-0.16.62.tgz: package/tests/e2e/dsl/component/widget/widget-tags.js <==
import {
    Action,
    ElementUtil,
    Expectation
} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

export const clickAddButton = () =>
    Action.click('.testComponent .react-tagsinput button');

export const expectAddButtonPresent = () =>
    Expectation.present('.testComponent .react-tagsinput button');

export const expectAddButtonNotPresent = () =>
    Expectation.notPresent('.testComponent .react-tagsinput button');

export const expectInputDisabled = () =>
    Expectation.disabled('.testComponent .react-tagsinput input');

export const expectInputEnabled = () =>
    Expectation.enabled('.testComponent .react-tagsinput input');

export const expectEmptyInputValue = () =>
    Expectation.attributeContainsValue('.testComponent .react-tagsinput input', 'value', '');

export const expectTagPresent = (tagNumber, tagText) =>
    Expectation.present(`.testComponent .react-tagsinput-tag:nth-child(${tagNumber})[title="${tagText}"]`);

export const expectTagNotPresent = (tagNumber) =>
    Expectation.notPresent(`.testComponent .react-tagsinput-tag:nth-child(${tagNumber})`);

export const expectClearForTagPresent = (tagNumber) => {
    const tagSelector = `.testComponent .react-tagsinput-tag:nth-child(${tagNumber})`;
    return Expectation.present(`${tagSelector} .react-tagsinput-remove`);
};

export const expectClearForTagNotPresent = (tagNumber, tagText) => {
    const tagSelector = `.testComponent .react-tagsinput-tag:nth-child(${tagNumber})[title="${tagText}"]`;
    return Expectation.notPresent(`${tagSelector} .react-tagsinput-remove`);
};

export const removeTag = (tagNumber) => {
    const tagSelector = `.testComponent .react-tagsinput-tag:nth-child(${tagNumber})`;
    return Action.click(`${tagSelector} .react-tagsinput-remove`);
};

export const setValue = (value) =>
    Action.typeText('.testComponent .react-tagsinput-input', value);

export const clickTabKey = () => {
    const element = ElementUtil.elementFinder('.testComponent .react-tagsinput input');
    return element.sendKeys(protractor.Key.TAB);
};

export const collapseTagsField = () =>
    Action.click('.xl-react-button.xl-primary.api-button.focus-btn');

export const expectRemainingTagsLabelPresent = () =>
    Expectation.present('.testComponent .remaining-tags');

export const expectRemainingTagsLabelNotPresent = () =>
    Expectation.notPresent('.testComponent .remaining-tags');

export const expandTagsField = () => {
    Action.click('.testComponent .remaining-tags');
    return expectRemainingTagsLabelNotPresent();
};

const WidgetTags = {
    ...XlComponent,
    clickAddButton,
    clickTabKey,
    collapseTagsField,
    expectInputEnabled,
    expectInputDisabled,
    expandTagsField,
    expectAddButtonPresent,
    expectAddButtonNotPresent,
    expectClearForTagNotPresent,
    expectClearForTagPresent,
    expectEmptyInputValue,
    expectRemainingTagsLabelNotPresent,
    expectRemainingTagsLabelPresent,
    expectTagPresent,
    expectTagNotPresent,
    removeTag,
    setValue
};

export default WidgetTags;
global.WidgetTags = WidgetTags;

==> xl-react-components-0.21.15.tgz: package/tests/e2e/dsl/component/widget/widget-tags.js <==
import {
    Action,
    ActionUtil,
    ElementUtil,
    Expectation,
    WaitCondition
} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

export const clickAddButton = () =>
    Action.click('.testComponent .react-tagsinput button');

export const expectAddButtonPresent = () =>
    Expectation.present('.testComponent .react-tagsinput button');

export const expectAddButtonNotPresent = () =>
    Expectation.notPresent('.testComponent .react-tagsinput button');

export const expectInputDisabled = () =>
    Expectation.disabled('.testComponent .react-tagsinput input');

export const expectInputEnabled = () =>
    Expectation.enabled('.testComponent .react-tagsinput input');

export const expectEmptyInputValue = () =>
    Expectation.attributeContainsValue('.testComponent .react-tagsinput input', 'value', '');

export const expectTagPresent = (tagNumber, tagText) =>
    Expectation.present(`.testComponent .react-tagsinput-tag:nth-child(${tagNumber})[title="${tagText}"]`);

export const expectTagNotPresent = (tagNumber) =>
    Expectation.notPresent(`.testComponent .react-tagsinput-tag:nth-child(${tagNumber})`);

export const expectClearForTagPresent = (tagNumber) => {
    const tagSelector = `.testComponent .react-tagsinput-tag:nth-child(${tagNumber})`;
    return Expectation.present(`${tagSelector} .react-tagsinput-remove`);
};

export const expectClearForTagNotPresent = (tagNumber, tagText) => {
    const tagSelector = `.testComponent .react-tagsinput-tag:nth-child(${tagNumber})[title="${tagText}"]`;
    return Expectation.notPresent(`${tagSelector} .react-tagsinput-remove`);
};

export const removeTag = (tagNumber) => {
    const tagSelector = `.testComponent .react-tagsinput-tag:nth-child(${tagNumber})`;
    return Action.click(`${tagSelector} .react-tagsinput-remove`);
};

export const setValue = (value) =>
    Action.typeText('.testComponent .react-tagsinput-input', value);

export const clickTabKey = () => {
    const element = ElementUtil.elementFinder('.testComponent .react-tagsinput input');
    return element.sendKeys(protractor.Key.TAB);
};

export const collapseTagsField = () => {
    Action.click('.xl-react-button.xl-primary.api-button.focus-btn');
    XlComponent.clickOnLabel();
};

export const expectRemainingTagsLabelPresent = () =>
    Expectation.present('.testComponent .remaining-tags');

export const expectRemainingTagsLabelNotPresent = () =>
    Expectation.notPresent('.testComponent .remaining-tags');

export const expandTagsField = () => {
    const action = () => Action.jsClick('.testComponent .remaining-tags');
    const condition = () => WaitCondition.notPresent('.testComponent .remaining-tags');
    ActionUtil.repeatAction(action, condition);
};

const WidgetTags = {
    ...XlComponent,
    clickAddButton,
    clickTabKey,
    collapseTagsField,
    expectInputEnabled,
    expectInputDisabled,
    expandTagsField,
    expectAddButtonPresent,
    expectAddButtonNotPresent,
    expectClearForTagNotPresent,
    expectClearForTagPresent,
    expectEmptyInputValue,
    expectRemainingTagsLabelNotPresent,
    expectRemainingTagsLabelPresent,
    expectTagPresent,
    expectTagNotPresent,
    removeTag,
    setValue
};

export default WidgetTags;
global.WidgetTags = WidgetTags;
